Documentation
¶
Index ¶
Constants ¶
const GroupName = "cloudcontrollermanager.config.k8s.io"
GroupName is the group name used in this package
Variables ¶
var ( // SchemeGroupVersion is group version used to register these objects SchemeGroupVersion = schema.GroupVersion{Group: GroupName, Version: runtime.APIVersionInternal} // SchemeBuilder is the scheme builder with scheme init functions to run for this API package SchemeBuilder = runtime.NewSchemeBuilder(addKnownTypes) // AddToScheme is a global function that registers this API group & version to a scheme AddToScheme = SchemeBuilder.AddToScheme )
Functions ¶
This section is empty.
Types ¶
type CloudControllerManagerConfiguration ¶
type CloudControllerManagerConfiguration struct {
metav1.TypeMeta
// Generic holds configuration for a generic controller-manager
Generic cmconfig.GenericControllerManagerConfiguration
// both in cloud controller manager and kube-controller manager.
KubeCloudShared KubeCloudSharedConfiguration
// ServiceControllerConfiguration holds configuration for ServiceController
// related features.
ServiceController serviceconfig.ServiceControllerConfiguration
// NodeStatusUpdateFrequency is the frequency at which the controller updates nodes' status
NodeStatusUpdateFrequency metav1.Duration
}
CloudControllerManagerConfiguration contains elements describing cloud-controller manager.
func (*CloudControllerManagerConfiguration) DeepCopy ¶
func (in *CloudControllerManagerConfiguration) DeepCopy() *CloudControllerManagerConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudControllerManagerConfiguration.
func (*CloudControllerManagerConfiguration) DeepCopyInto ¶
func (in *CloudControllerManagerConfiguration) DeepCopyInto(out *CloudControllerManagerConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
func (*CloudControllerManagerConfiguration) DeepCopyObject ¶
func (in *CloudControllerManagerConfiguration) DeepCopyObject() runtime.Object
DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.
type CloudProviderConfiguration ¶
type CloudProviderConfiguration struct {
// Name is the provider for cloud services.
Name string
// cloudConfigFile is the path to the cloud provider configuration file.
CloudConfigFile string
}
CloudProviderConfiguration contains basically elements about cloud provider.
func (*CloudProviderConfiguration) DeepCopy ¶
func (in *CloudProviderConfiguration) DeepCopy() *CloudProviderConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new CloudProviderConfiguration.
func (*CloudProviderConfiguration) DeepCopyInto ¶
func (in *CloudProviderConfiguration) DeepCopyInto(out *CloudProviderConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.
type KubeCloudSharedConfiguration ¶
type KubeCloudSharedConfiguration struct {
CloudProvider CloudProviderConfiguration
// It is currently used by the in repo cloud providers to handle node and volume control in the KCM.
ExternalCloudVolumePlugin string
// individual service account credentials.
UseServiceAccountCredentials bool
AllowUntaggedCloud bool
RouteReconciliationPeriod metav1.Duration
NodeMonitorPeriod metav1.Duration
ClusterName string
ClusterCIDR string
// ConfigureCloudRoutes is true, to be set on the cloud provider.
AllocateNodeCIDRs bool
CIDRAllocatorType string
// to be configured on the cloud provider.
ConfigureCloudRoutes bool
// periods will result in fewer calls to cloud provider, but may delay addition
// of new nodes to cluster.
NodeSyncPeriod metav1.Duration
}
KubeCloudSharedConfiguration contains elements shared by both kube-controller manager and cloud-controller manager, but not genericconfig.
func (*KubeCloudSharedConfiguration) DeepCopy ¶
func (in *KubeCloudSharedConfiguration) DeepCopy() *KubeCloudSharedConfiguration
DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new KubeCloudSharedConfiguration.
func (*KubeCloudSharedConfiguration) DeepCopyInto ¶
func (in *KubeCloudSharedConfiguration) DeepCopyInto(out *KubeCloudSharedConfiguration)
DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.